@@ -16,15 +16,15 @@
 
 import csv
 import datetime
+from io import StringIO
 import sys
 import unittest
 
 from testtools import TestCase
-from testtools.compat import StringIO
 from testtools.content import (
     text_content,
     TracebackContent,
-    )
+)
 from testtools.testresult.doubles import ExtendedTestResult
 
 import subunit
@@ -377,10 +377,7 @@ class TestByTestResultTests(testtools.TestCase):
         super(TestByTestResultTests, self).setUp()
         self.log = []
         self.result = subunit.test_results.TestByTestResult(self.on_test)
-        if sys.version_info >= (3, 0):
-            self.result._now = iter(range(5)).__next__
-        else:
-            self.result._now = iter(range(5)).next
+        self.result._now = iter(range(5)).__next__
 
     def assertCalled(self, **kwargs):
         defaults = {
@@ -536,10 +533,7 @@ class TestCsvResult(testtools.TestCase):
     def test_csv_output(self):
         stream = StringIO()
         result = subunit.test_results.CsvResult(stream)
-        if sys.version_info >= (3, 0):
-            result._now = iter(range(5)).__next__
-        else:
-            result._now = iter(range(5)).next
+        result._now = iter(range(5)).__next__
         result.startTestRun()
         result.startTest(self)
         result.addSuccess(self)
